@@ -31,3 +31,7 @@ elif "Pybadge" in os.uname().machine:
     from .pybadge import pybadge as pybadger
 elif "PyGamer" in os.uname().machine:
     from .pygamer import pygamer as pybadger
+elif "PewPew M4" in os.uname().machine:
+    from .pewpewm4 import pewpewm4 as pybadger
+elif "PyPortal" in os.uname().machine:
+    from .pyportal import pyportal as pybadger
